.. include:: header.rst


.. include:: tcshow_help.rst
.. include:: usage.rst

.. note::

    Scope of ``tcshow`` command is limited to parameters that can be set with tcset
    (i.e. ``tcshow`` is not a general purpose tool to display all of the parameters of the tc command).

.. note::

    ``tcshow`` may output improper values when using ``tbf``.
